@@ -9,7 +9,7 @@
 package Dist::Zilla::Role::Git::Repo;
 # ABSTRACT: Provide repository information for Git plugins
 
-our $VERSION = '2.040';
+our $VERSION = '2.042';
 
 use Moose::Role;
 use MooseX::Types::Moose qw(Str Maybe);
@@ -70,7 +70,7 @@ around dump_config => sub
 
     $config->{+__PACKAGE__} = {
         repo_root => $self->repo_root,
-        'git --version' => $self->git('version'),
+        git_version => $self->git->version,
     };
 
     return $config;
@@ -99,7 +99,7 @@ Dist::Zilla::Role::Git::Repo - Provide repository information for Git plugins
 
 =head1 VERSION
 
-version 2.040
+version 2.042
 
 =head1 DESCRIPTION
 
@@ -137,7 +137,7 @@ Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Di
 (or L<bug-Dist-Zilla-Plugin-Git@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git@rt.cpan.org>).
 
 There is also a mailing list available for users of this distribution, at
-L<http://www.listbox.com/subscribe/?list_id=139292>.
+L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
 L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
